==> zzyj-outputvalcount-impl-3.0.0-20230620.000638-191-sources.jar: com/ejianc/business/outputvalcount/bean/ProjectInfoRegisterExamineEntity.java <==
package com.ejianc.business.outputvalcount.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 信息每日填报行政部门检查
 * 
 * @author generator
 * 
 */
 @TableName("t_project_info_register_examine")
public class ProjectInfoRegisterExamineEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="project_id")
    private Long projectId; // 工程名称id
    @TableField(value="project_name")
    private String projectName; // 工程名称
    @TableField(value="create_date")
    private Date createDate; // 创建日期
    @TableField(value="examine_org_id")
    private Long examineOrgId; // 检查单位ID
    @TableField(value="examine_org_name")
    private String examineOrgName; // 检查单位
    @TableField(value="examine_state")
    private Integer examineState; // 是否下发整改通知 1是2否
    @TableField(value="dispute_state")
    private Integer disputeState; // 是否下发行政处罚 1是2否
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="zhu_id")
    private Long zhuId; // 主表ID
    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }
    public Long getExamineOrgId() {
        return examineOrgId;
    }

    public void setExamineOrgId(Long examineOrgId) {
        this.examineOrgId = examineOrgId;
    }
    public String getExamineOrgName() {
        return examineOrgName;
    }

    public void setExamineOrgName(String examineOrgName) {
        this.examineOrgName = examineOrgName;
    }
    public Integer getExamineState() {
        return examineState;
    }

    public void setExamineState(Integer examineState) {
        this.examineState = examineState;
    }
    public Integer getDisputeState() {
        return disputeState;
    }

    public void setDisputeState(Integer disputeState) {
        this.disputeState = disputeState;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getZhuId() {
        return zhuId;
    }

    public void setZhuId(Long zhuId) {
        this.zhuId = zhuId;
    }
    
}

==> zzyj-outputvalcount-impl-3.0.0-20250801.043202-368-sources.jar: com/ejianc/business/outputvalcount/bean/ProjectInfoRegisterExamineEntity.java <==
package com.ejianc.business.outputvalcount.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 信息每日填报行政部门检查
 * 
 * @author generator
 * 
 */
 @TableName("t_project_info_register_examine")
public class ProjectInfoRegisterExamineEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="project_id")
    private Long projectId; // 工程名称id
    @TableField(value="project_name")
    private String projectName; // 工程名称
    @TableField(value="create_date")
    private Date createDate; // 创建日期
    @TableField(value="examine_org_id")
    private Long examineOrgId; // 检查单位ID
    @TableField(value="examine_org_name")
    private String examineOrgName; // 检查单位
    @TableField(value="examine_state")
    private String examineState; // 是否下发整改通知 1是2否
    @TableField(value="dispute_state")
    private String disputeState; // 是否下发行政处罚 1是2否
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="zhu_id")
    private Long zhuId; // 主表ID
    @TableField(value="check_type")
    private String checkType; // 检查类型
    @TableField(value="check_info")
    private String checkInfo; // 检查内容
    @TableField(value="treatment_progress")
    private String treatmentProgress; // 处理进展
    @TableField(value="treatment_result")
    private String treatmentResult; // 处理结果
    @TableField(value="finish_time")
    private Date finishTime; // 完结时间


    public String getCheckType() {
        return checkType;
    }

    public void setCheckType(String checkType) {
        this.checkType = checkType;
    }

    public String getCheckInfo() {
        return checkInfo;
    }

    public void setCheckInfo(String checkInfo) {
        this.checkInfo = checkInfo;
    }

    public String getTreatmentProgress() {
        return treatmentProgress;
    }

    public void setTreatmentProgress(String treatmentProgress) {
        this.treatmentProgress = treatmentProgress;
    }

    public String getTreatmentResult() {
        return treatmentResult;
    }

    public void setTreatmentResult(String treatmentResult) {
        this.treatmentResult = treatmentResult;
    }

    public Date getFinishTime() {
        return finishTime;
    }

    public void setFinishTime(Date finishTime) {
        this.finishTime = finishTime;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }
    public Long getExamineOrgId() {
        return examineOrgId;
    }

    public void setExamineOrgId(Long examineOrgId) {
        this.examineOrgId = examineOrgId;
    }
    public String getExamineOrgName() {
        return examineOrgName;
    }

    public void setExamineOrgName(String examineOrgName) {
        this.examineOrgName = examineOrgName;
    }
    public String getExamineState() {
        return examineState;
    }

    public void setExamineState(String examineState) {
        this.examineState = examineState;
    }
    public String getDisputeState() {
        return disputeState;
    }

    public void setDisputeState(String disputeState) {
        this.disputeState = disputeState;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getZhuId() {
        return zhuId;
    }

    public void setZhuId(Long zhuId) {
        this.zhuId = zhuId;
    }
    
}
